#'Register Exponential Family Functional Data
#'
#' Software for registering functional data from the exponential family of distributions.
#' 
#' @author Julia Wrobel
#'
#' @useDynLib registr
#' @importFrom Rcpp evalCpp
"_PACKAGE"
